<?php
/**
* Dynamic To Top Options
*
* @package Dynamic To Top
* @subpackage Options
* @author Matt Varone
*/

add_action('admin_menu', 'mv_dynamic_to_top_create_options_page');
add_action('admin_init', 'mv_dynamic_to_top_register_and_build_fields');

if ( !function_exists('mv_dynamic_to_top_create_options_page') )
{
	
	/** 
	* Create Options Page 
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_create_options_page() 
	{
		// Create Options Page
		add_options_page('Dynamic To Top Options','Dynamic To Top', 'manage_options', __FILE__, 'mv_dynamic_to_top_options_page');
	}
}

if ( !function_exists('mv_dynamic_to_top_register_and_build_fields') )
{
	
	/** 
	* Register and Build Fields
	*
	* Register fields and sections.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_register_and_build_fields() 
	{
		register_setting('dynamic_to_top', 'dynamic_to_top','mv_dynamic_to_top_save_settings');

		add_settings_section('settings_section', __('Behavior', MV_DYNAMIC_TO_TOP_DOMAIN),'__return_true',__FILE__);
		add_settings_section('appearance_section', __('Appearance', MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_appearance_section',__FILE__);

		add_settings_field('speed',__('Scroll time',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_scroll_time',__FILE__,'settings_section');
		add_settings_field('distance',__('Fade-in distance',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_distance',__FILE__,'settings_section');
		add_settings_field('easing',__('Easing',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_easing',__FILE__,'settings_section');
		add_settings_field('position',__('Position',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_position',__FILE__,'settings_section');
		add_settings_field('prevent_on_mobile',__('Prevent on mobile',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_prevent_on_mobile',__FILE__,'settings_section');
			
		add_settings_field('text_version',__('Text version',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_text_version',__FILE__,'appearance_section');
		add_settings_field('text',__('Button text',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_text',__FILE__,'appearance_section');
		add_settings_field('padding_top_bottom',__('Top/bottom padding',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_padding_top_bottom',__FILE__,'appearance_section');
		add_settings_field('padding_left_right',__('Sides padding',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_padding_left_right',__FILE__,'appearance_section');
		add_settings_field('font_size',__('Font size',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_font_size',__FILE__,'appearance_section');
		add_settings_field('text_color',__('Text color',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_text_color',__FILE__,'appearance_section');
		add_settings_field('bold',__('Bold Text',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_bold',__FILE__,'appearance_section');		
		add_settings_field('text_shadow',__('Text shadow',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_text_shadow',__FILE__,'appearance_section');		
		add_settings_field('shadow_color',__('Text shadow color',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_text_shadow_color',__FILE__,'appearance_section');		
		add_settings_field('background_color',__('Background color',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_background_color',__FILE__,'appearance_section');
		add_settings_field('border_color',__('Border color',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_border_color',__FILE__,'appearance_section');
		add_settings_field('border_width',__('Border width',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_border_width',__FILE__,'appearance_section');
		add_settings_field('radius',__('Border radius',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_border_radius',__FILE__,'appearance_section');
		add_settings_field('inset',__('Inset highlighting',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_inset',__FILE__,'appearance_section');		
		add_settings_field('shadow',__('Shadow',MV_DYNAMIC_TO_TOP_DOMAIN),'mv_dynamic_to_top_field_shadow',__FILE__,'appearance_section');

	}
}

/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTIONS PAGE
|--------------------------------------------------------------------------
*/

if ( !function_exists('mv_dynamic_to_top_options_page') )
{
	/** 
	* Options Page
	*
	* Options page layout.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_options_page() 
	{
		
	?>
	<div class="wrap"> 
		<?php screen_icon(); ?> 
		<h2><?php _e('Dynamic To Top Options', MV_DYNAMIC_TO_TOP_DOMAIN); ?></h2> 
		
		<p><?php _e('Welcome to the <strong>Dynamic To Top</strong> plugin settings. Click <a href="http://www.mattvarone.com/featured-content/dynamic-to-top/" target="_blank">here</a> to learn more about this plugin.',MV_DYNAMIC_TO_TOP_DOMAIN); ?></p>
		

		<form method="post" action="options.php" enctype="multipart/form-data">
			<?php settings_fields('dynamic_to_top'); ?>
			<?php do_settings_sections(__FILE__); ?>

		       <p class="submit">
		          <input name="Submit" type="submit" class="button-primary" value="<?php _e('Save Changes', MV_DYNAMIC_TO_TOP_DOMAIN); ?>" />
		       </p>
		
			<p><small><?php _e('<strong>Dynamic To Top</strong> plugin brought to you by',MV_DYNAMIC_TO_TOP_DOMAIN); ?> <a href="http://www.mattvarone.com" title="Matt Varone" target="_blank"><strong>Matt Varone</strong></a>.</small></p>
		
		</form>
	</div>
	<?php
	}

}

if ( !function_exists('mv_dynamic_to_top_appearance_section') )
{
	function mv_dynamic_to_top_appearance_section()
	{
		echo '<div id="dynamic-to-top-preview"><div id="dynamic-to-top-button"><span id="dtt-text"></span><span id="dtt-image"></span></div></div>';
		echo '<p class="ddt-bg-colors"><small>'.__('Preview over',MV_DYNAMIC_TO_TOP_DOMAIN).' <a href="#" title="black">'.__('black',MV_DYNAMIC_TO_TOP_DOMAIN).'</a>, <a href="#" title="lightgrey">'.__('grey',MV_DYNAMIC_TO_TOP_DOMAIN).'</a> or <a href="#" title="white">'.__('white',MV_DYNAMIC_TO_TOP_DOMAIN).'</a>.</small></p>';
	}
}

if ( !function_exists('mv_dynamic_to_top_save_settings') )
{
	function mv_dynamic_to_top_save_settings($options)
	{
		delete_transient('dynamic_to_top_transient_css');
		delete_transient('dynamic_to_top_transient_js');
		
		return $options;
	}
}

/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTIONS PAGE ASSETS
|--------------------------------------------------------------------------
*/

if ( !function_exists('mv_dynamic_to_top_styles') )
{
	/** 
	* Options page enqueue style.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_styles()
	{		
		if (mv_dynamic_to_top_is_page_options()) {
			wp_enqueue_style('farbtastic');
			wp_enqueue_style('dynamic-to-top-jquery-ui', MV_DYNAMIC_TO_TOP_URL.'/css/dynamic-to-top-jquery-ui.css',array(),'1.8.13');
			wp_enqueue_style('dynamic-to-top-admin', MV_DYNAMIC_TO_TOP_URL.'/css/dynamic-to-top-admin.css',array('dynamic-to-top-jquery-ui'),MV_DYNAMIC_TO_TOP_VERSION);
		}
	}
	
	add_action( 'admin_print_styles', 'mv_dynamic_to_top_styles' );
}

if ( !function_exists('mv_dynamic_to_top_scripts') )
{
	
	/** 
	* Options page enqueue script.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_scripts() 
	{
		if (mv_dynamic_to_top_is_page_options())
		{
			wp_enqueue_script('jquery-ui-widget', MV_DYNAMIC_TO_TOP_URL.'/js/libs/jquery.ui.widget.js', array('jquery-ui-core'),'1.8.14');
			wp_enqueue_script('jquery-ui-mouse', MV_DYNAMIC_TO_TOP_URL.'/js/libs/jquery.ui.mouse.js', array('jquery-ui-widget'),'1.8.14');
			wp_enqueue_script('jquery-ui-slider', MV_DYNAMIC_TO_TOP_URL.'/js/libs/jquery.ui.slider.js', array('jquery-ui-mouse'),'1.8.14');
			wp_enqueue_script('dynamic-to-top-settings',MV_DYNAMIC_TO_TOP_URL.'/js/dynamic.to.top.settings.js',array('jquery-ui-slider','farbtastic'),'1.0',true);
		}
	}
	
	add_action( 'admin_print_scripts', 'mv_dynamic_to_top_scripts' );
}

if ( !function_exists('mv_dynamic_to_top_is_page_options') )
{
	
	/** 
	* Is dynamic to top page options?
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	* @return boolean 
	*
	*/
	
	function mv_dynamic_to_top_is_page_options()
	{
		global $pagenow;
		
		if (function_exists('get_current_screen')) 
		{
			$screen = get_current_screen();
			
			if ( isset($screen->base) && $screen->base == 'settings_page_'.MV_DYNAMIC_TO_TOP_FOLDER.'/inc/dynamic-to-top-options')
				return true;
			else
				return false;
		} 
		else 
		{
			$pages = array('options-general.php');

			if (in_array($pagenow, $pages) && isset($_GET['page']) && $_GET['page'] == MV_DYNAMIC_TO_TOP_FOLDER.'/inc/dynamic-to-top-options.php')
			return true;
		}
		
		return false;
	}
}

/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTIONS PAGE FIELDS
|--------------------------------------------------------------------------
*/

//	COLOR PICKERS ///////////////////////// 

if ( !function_exists('mv_dynamic_to_top_field_border_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_border_color() 
	{
		echo mv_dynamic_to_top_do_textfield_color('border_color','#000',__('Color for the button border.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_background_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_background_color() 
	{
		echo mv_dynamic_to_top_do_textfield_color('background_color','#111',__('Background color for the button.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_text_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_text_color() 
	{
		echo mv_dynamic_to_top_do_textfield_color('text_color','#fff',__('Button text color.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_text_shadow_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_text_shadow_color() 
	{
		echo mv_dynamic_to_top_do_textfield_color('shadow_color','#333',__('Text shadow color.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_box_shadow_color') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_box_shadow_color() 
	{
		echo mv_dynamic_to_top_do_textfield_color('box_shadow_color','#333',__('Text shadow color.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

// SELECT BOX ///////////////////////// 

if ( !function_exists('mv_dynamic_to_top_field_easing') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_easing() 
	{
		$options = array( 'Linear', 'In','Out','In Out','Bounce','Elastic');
		
		echo mv_dynamic_to_top_do_select('easing',$options,'In',__('<a href="http://gsgd.co.uk/sandbox/jquery/easing" title="Easing type">Easing type</a> used to scroll the page up.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_position') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_position() 
	{
		$options = array( 'Top Left', 'Top Right', 'Bottom Left', 'Bottom Right');
		
		echo mv_dynamic_to_top_do_select('position',$options,'Bottom Right',__('Button position.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

// SLIDER UI ///////////////////////// 

if ( !function_exists('mv_dynamic_to_top_field_scroll_time') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_scroll_time() 
	{
		echo mv_dynamic_to_top_do_slider('speed',1100,__('Time it takes for the page to scroll up. Less for faster. ( <span id="speed-val"></span> Milliseconds )',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_font_size') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_font_size() 
	{
		echo mv_dynamic_to_top_do_slider('font_size',1,__('Button text size. ( <span id="font-size-val"></span> Em/s )',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_padding_top_bottom') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_padding_top_bottom() 
	{
		echo mv_dynamic_to_top_do_slider('padding_top_bottom',21,__('Spacing on Top and Bottom. ( <span id="padding-top-bottom-val"></span>px )',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_padding_left_right') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_padding_left_right() 
	{
		echo mv_dynamic_to_top_do_slider('padding_left_right',19,__('Spacing on Left and Right. ( <span id="padding-left-right-val"></span>px )',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_border_width') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_border_width() 
	{
		echo mv_dynamic_to_top_do_slider('border_width','1',__('Button border width',MV_DYNAMIC_TO_TOP_DOMAIN).' <span id="border-val"></span>px.');
	}
}

if ( !function_exists('mv_dynamic_to_top_field_border_radius') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_border_radius() 
	{
		echo mv_dynamic_to_top_do_slider('radius','9',__('Button border radius',MV_DYNAMIC_TO_TOP_DOMAIN).' <span id="radius-val"></span>px.');
	}
}

// TEXTFIELDS ///////////////////////// 

if ( !function_exists('mv_dynamic_to_top_field_distance') )
{

	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/

	function mv_dynamic_to_top_field_distance() 
	{
		echo mv_dynamic_to_top_do_textfield('distance',300,__('Distance from top to show the button. ( Pixels )',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_text') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_text() 
	{
		echo mv_dynamic_to_top_do_textfield('text',__('To Top',MV_DYNAMIC_TO_TOP_DOMAIN),__('Text displayed on the button.',MV_DYNAMIC_TO_TOP_DOMAIN),'regular-text');
	}
}

// CHECKBOXES ///////////////////////// 

if ( !function_exists('mv_dynamic_to_top_field_prevent_on_mobile') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_prevent_on_mobile() 
	{
		echo mv_dynamic_to_top_do_checkbox('prevent_on_mobile',__('Yes',MV_DYNAMIC_TO_TOP_DOMAIN),'yes',false,__('Disable the button on mobile browsers.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_text_version') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_text_version() 
	{
		echo mv_dynamic_to_top_do_checkbox('text_version',__('Yes',MV_DYNAMIC_TO_TOP_DOMAIN),'yes',false,__('Show a text version instead of the arrow up icon.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_inset') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_inset() 
	{
		echo mv_dynamic_to_top_do_checkbox('inset',__('Yes',MV_DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Add CSS3 inset-highlight.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_shadow') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_shadow() 
	{
		echo mv_dynamic_to_top_do_checkbox('shadow',__('Yes',MV_DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Add CSS3 shadow.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_weight') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_bold() 
	{
		echo mv_dynamic_to_top_do_checkbox('bold',__('Yes',MV_DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Make the text bold.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}

if ( !function_exists('mv_dynamic_to_top_field_text_shadow') )
{
	
	/** 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_field_text_shadow() 
	{
		echo mv_dynamic_to_top_do_checkbox('text_shadow',__('Yes',MV_DYNAMIC_TO_TOP_DOMAIN),'yes',true,__('Add a subtle text shadow.',MV_DYNAMIC_TO_TOP_DOMAIN));
	}
}
/*
|--------------------------------------------------------------------------
| DYNAMIC TO TOP OPTION FIELDS HELPERS
|--------------------------------------------------------------------------
*/

if ( !function_exists('mv_dynamic_to_top_do_checkbox') )
{
	
	/** 
	* Do Checkbox
	*
	* Generates a checkbox.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_do_checkbox($meta,$label="Yes",$value='yes',$checked=false,$desc="")
	{

		$options_db = get_option('dynamic_to_top');

		if (isset($options_db[$meta]) && $options_db[$meta] == $value) 
			$c = 'checked="checked"'; 
		else
			$c="";
			
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

		return '<input type="checkbox" name="dynamic_to_top['.$meta.']" value="'.$value.'" '.$c.' id="checkbox-'.$sanitized_meta_title.'" /> '.$label.$desc;	
	}
}

if ( !function_exists('mv_dynamic_to_top_do_textfield') )
{
	
	/** 
	* Do Textfield
	*
	* Generates a Textfield.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_do_textfield($meta,$value="",$desc="",$class="")
	{

		$options_db = get_option('dynamic_to_top');

		if ( isset($options_db[$meta])) 
		$value = $options_db[$meta]; 
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		if ( $class != "")
		$class = 'class="'.$class.'"';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));
		
		return '<input type="text" id="text-'.$sanitized_meta_title.'" name="dynamic_to_top['.$meta.']" '.$class.' value="'.$value.'" /> '.$desc;	
	}
}

if ( !function_exists('mv_dynamic_to_top_do_select') )
{
	
	/** 
	* Do Select Box
	*
	* Generate a select box.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_do_select($meta,$options=array(),$value="",$desc="")
	{

		$options_out  = "";
		
		$options_db = get_option('dynamic_to_top');
		
		if ( isset($options_db[$meta]))
		$value = $options_db[$meta];
		
		$value = sanitize_title($value);

		foreach ($options as $option) 
		{
			$selected = "";
			
			$option_slug = sanitize_title($option);
			
			if ( $value == $option_slug )
			$selected = 'selected="selected"'; 
			
			$options_out .= '<option name="'.sanitize_title($option).'" '.$selected.' >'.$option.'</option>';
		}
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

	   return '<select name="dynamic_to_top['.$meta.']" id="select-'.$sanitized_meta_title.'"> '.$options_out.'</select>'.$desc;	
	}
}

if ( !function_exists('mv_dynamic_to_top_do_textfield_color') )
{
	
	/** 
	* Do Textfield Color
	*
	* Generates a Textfield with Farbtastic.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_do_textfield_color($meta,$value="",$desc="",$class="")
	{

		$options_db = get_option('dynamic_to_top');

		if ( isset($options_db[$meta])) 
		$value = $options_db[$meta]; 
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		if ( $class != "") 
		$class .= " ";
		
		$class = 'class="'.$class.'colorvalue"';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

		$out  = '<input type="text" name="dynamic_to_top['.$meta.']" id="farbtastic-'.$sanitized_meta_title.'" '.$class.' value="'.$value.'" />';
		$out .= '<a class="picker hide-if-no-js" href="#" data-closed="'.__('close',MV_DYNAMIC_TO_TOP_DOMAIN).'" data-open="'.__('select a color',MV_DYNAMIC_TO_TOP_DOMAIN).'">'.__('select a color',MV_DYNAMIC_TO_TOP_DOMAIN).'</a>';
		$out .= '<div id="farbtastic-picker-'.$sanitized_meta_title.'" class="dtt-farbtastic"></div>';
		$out .= $desc;
		
		return $out;
	}
}

if ( !function_exists('mv_dynamic_to_top_do_slider') )
{
	
	/** 
	* Do Textfield Color
	*
	* Generates a Textfield with a slider.
	* 
	* @package Dynamic To Top
	* @subpackage Options
	* @since 3.0
	*
	*/
	
	function mv_dynamic_to_top_do_slider($meta,$value="",$desc="",$class="")
	{

		$options_db = get_option('dynamic_to_top');

		if ( isset($options_db[$meta])) 
		$value = $options_db[$meta]; 
		
	   	if ( $desc != "")
		$desc = '<div class="desc">'.$desc.'</div>';
		
		if ( $class != "") 
		$class .= " ";
		
		$class = 'class="'.$class.'colorvalue"';
		
		$sanitized_meta_title = str_replace('_','-',sanitize_title($meta));

	   return '<div id="slider-picker-'.$sanitized_meta_title.'" class="dtt-slider"></div><input type="text" name="dynamic_to_top['.$meta.']" id="slider-'.$sanitized_meta_title.'" '.$class.' value="'.$value.'" />'.$desc;	
	}
}